JuiButtonColorConfig class

按钮颜色配置类

Constructors

JuiButtonColorConfig({required Color getColor(bool disable), required Color getFontColor(bool disable), BoxBorder? border})
创建一个按钮颜色配置对象
const

Properties

border → BoxBorder?
按钮边框,可选属性
final
getColor → Color Function(bool disable)
获取按钮背景颜色的函数,根据按钮是否禁用返回不同颜色
final
getFontColor → Color Function(bool disable)
获取按钮字体颜色的函数,根据按钮是否禁用返回不同颜色
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited