JuiDashedBorder class

JuiDashedBorder 组件用于创建带有虚线边框的容器。

该组件支持自定义虚线的颜色、宽度、高度、间距以及圆角半径,并且可以包含子组件。 用户还可以设置 onTap 回调,使整个边框区域可点击。

Inheritance

Constructors

JuiDashedBorder({Key? key, Color? dashColor, double dashWidth = 2, double dashHeight = 1, double dashSpace = 2, double borderRadius = 8, required Widget child, VoidCallback? onTap})
创建一个 JuiDashedBorder 组件
const

Properties

borderRadius → double
边框的圆角半径
final
child → Widget
虚线边框内部包含的子组件
final
dashColor → Color?
虚线的颜色,默认为主题色 primary
final
dashHeight → double
虚线的高度
final
dashSpace → double
虚线之间的间距
final
dashWidth → double
虚线的宽度
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
当用户点击虚线边框时触发的回调函数(可选)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited