JuiNoContent class

JuiNoContent 组件用于显示空页面的占位内容。

该组件可用于列表为空、搜索无结果等场景,并支持自定义图片和文本。

Inheritance

Constructors

JuiNoContent({Key? key, double paddingTop = 130, String text = "暂无数据", required JuiNoContentType type, String? imagePath, double imageWidth = 180, double paddingBottom = 0})
创建一个 JuiNoContent 组件
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imagePath → String?
自定义图片路径(仅在 JuiNoContentType.custom 类型下使用)
final
imageWidth → double
图片宽度
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
paddingBottom → double
底部填充
final
paddingTop → double
顶部填充
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
显示的文本内容
final
type → JuiNoContentType
JuiNoContent 组件的类型
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited