JuiTag class

JuiTag 组件用于显示各种标签。

该组件支持自定义文本、颜色、形状、字体大小,并可选择添加图标。

Inheritance

Constructors

JuiTag({Key? key, required String text, double paddingVertical = 2, double paddingHorizontal = 10, JuiTagType tagType = JuiTagType.text, JuiTagShapeType tagShapeType = JuiTagShapeType.rectangle, JuiTagColorType tagColorType = JuiTagColorType.blue, Widget? icon, double fontSize = 12, Alignment alignment = Alignment.center})
创建一个 JuiTag 组件
const

Properties

alignment → Alignment
文本的对齐方式
final
fontSize → double
文本的字体大小
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
标签左侧的可选图标(仅在 JuiTagType.icon 下有效)
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
paddingHorizontal → double
标签的水平内边距
final
paddingVertical → double
标签的垂直内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagColorType → JuiTagColorType
标签的颜色类型
final
tagShapeType → JuiTagShapeType
标签的形状类型
final
tagType → JuiTagType
标签类型(文本或带图标)
final
text → String
标签显示的文本内容
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited