JuiPickerHeaderConfig class

Constructors

JuiPickerHeaderConfig({String? title, Widget? customHeader, String? cancelText = JuiSelectPickerUIHelper.defaultCancelText, String? confirmText = JuiSelectPickerUIHelper.defaultConfirmText, TextStyle? cancelTextStyle, TextStyle? confirmTextStyle, bool? showHeader, bool? showConfirmButton, VoidCallback? tapConfirm})
const

Properties

cancelText → String?
final
cancelTextStyle → TextStyle?
final
confirmText → String?
final
confirmTextStyle → TextStyle?
final
customHeader → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showConfirmButton → bool?
final
showHeader → bool?
final
tapConfirm → VoidCallback?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited