JuiSelectPickerConfig class

Constructors

JuiSelectPickerConfig({required JuiSelectPickerLayout layout, required JuiPickerHeaderConfig headerConfig, SelectionMode selectionMode = SelectionMode.single, JuiSelectPickerUIConfig? uiConfig, JuiSelectPickerItemBuilder? customItemBuilder})

Properties

customItemBuilder → JuiSelectPickerItemBuilder?
final
hashCode → int
The hash code for this object.
no setterinherited
headerConfig → JuiPickerHeaderConfig
final
layout → JuiSelectPickerLayout
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionMode → SelectionMode
final
uiConfig → JuiSelectPickerUIConfig
final

Methods

copyWith({JuiSelectPickerLayout? layout, SelectionMode? selectionMode, JuiSelectPickerUIConfig? uiConfig, JuiPickerHeaderConfig? headerConfig, JuiSelectPickerItemBuilder? customItemBuilder}) → JuiSelectPickerConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited