JuiSelectPickerContentBuildParams class

Constructors

JuiSelectPickerContentBuildParams({required BuildContext context, required List<JuiSelectPickerItemUI> items, required List<JuiSelectPickerItemData> selectedItems, required JuiSelectPickerConfig config, required JuiSelectItemCallback onItemTap, JuiSelectItemCallback? onImmediateConfirm})
const

Properties

config → JuiSelectPickerConfig
final
context → BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<JuiSelectPickerItemUI>
final
onImmediateConfirm → JuiSelectItemCallback?
final
onItemTap → JuiSelectItemCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItems → List<JuiSelectPickerItemData>
final

Methods

isSelected(JuiSelectPickerItemUI item) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited