JuiSelectPickerUIConfig class

Constructors

JuiSelectPickerUIConfig({BorderRadius? topBorderRadius, Color backgroundColor = JuiSelectPickerUIHelper.defaultBackgroundColor, double? maxHeight, Color barrierColor = JuiSelectPickerUIHelper.defaultBarrierColor, bool isScrollControlled = JuiSelectPickerUIHelper.defaultIsScrollControlled, bool enableDrag = JuiSelectPickerUIHelper.defaultEnableDrag, TextStyle? itemTextStyle, Color? selectedItemColor, int? maxLines, bool shrinkWrap = true})

Properties

backgroundColor → Color
final
barrierColor → Color
final
enableDrag → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isScrollControlled → bool
final
itemTextStyle → TextStyle?
final
maxHeight → double
final
maxLines → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemColor → Color?
final
shrinkWrap → bool
final
topBorderRadius → BorderRadius
final

Methods

copyWith({BorderRadius? topBorderRadius, Color? backgroundColor, double? maxHeight, Color? barrierColor, bool? isScrollControlled, bool? enableDrag, TextStyle? itemTextStyle, Color? selectedItemColor, int? maxLines, bool? shrinkWrap}) → JuiSelectPickerUIConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited