TimePickerModel class

Constructors

TimePickerModel({DateTime? selectedTime, DateTime? startTime, DateTime? endTime})

Properties

endTime → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedTime → DateTime?
final
startTime → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited