JuiDialogConfig class

Constructors

JuiDialogConfig({String title = "", String confirmButtonText = "确定", String cancelButtonText = "取消", VoidCallback? onConfirm, VoidCallback? onCancel, bool showCancelButton = true, double dialogWidth = 327})

Properties

cancelButtonText → String
final
confirmButtonText → String
final
dialogWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
onCancel → VoidCallback?
final
onConfirm → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCancelButton → bool
final
title → String
final

Methods

copyWith({String? title, String? confirmButtonText, String? cancelButtonText, VoidCallback? onConfirm, VoidCallback? onCancel, bool? showCancelButton, double? dialogWidth}) → JuiDialogConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited