JuiItemConfig class

Constructors

JuiItemConfig({bool isRequired = false, bool isDisabled = false, Widget? titleSuffixWidget, Widget? titleBeforeRequiredWidget, Widget? requiredMarker, TextStyle? customTitleStyle, bool showDivider = true, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? dividerPadding, bool showTips = false, String tipText = '', VoidCallback? onTap, String? semanticsLabel, bool excludeSemantics = true})
const

Properties

customTitleStyle → TextStyle?
final
dividerPadding → EdgeInsetsGeometry?
final
excludeSemantics → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isDisabled → bool
final
isRequired → bool
final
onTap → VoidCallback?
final
padding → EdgeInsetsGeometry?
final
requiredMarker → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
final
showDivider → bool
final
showTips → bool
final
tipText → String
final
titleBeforeRequiredWidget → Widget?
final
titleSuffixWidget → Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited